﻿namespace U2UC.Metro.ConverterParameterBinding
{
    using System;
    using Windows.UI;
    using Windows.UI.Xaml;
    using Windows.UI.Xaml.Data;
    using Windows.UI.Xaml.Media;

    /// <summary>
    /// Returns a Brush indicating whether or not the value is in a range.
    /// </summary>
    public class RangeValidationConverter : DependencyObject, IValueConverter
    {
        /// <summary>
        /// Gets or sets the range to compare the value with.
        /// </summary>
        public Range<int> Range
        {
            get { return (Range<int>)GetValue(RangeProperty); }
            set { SetValue(RangeProperty, value); }
        }

        public static readonly DependencyProperty RangeProperty =
            DependencyProperty.Register("Range", typeof(Range<int>), typeof(RangeValidationConverter), new PropertyMetadata(new Range<int>(0,100)));

        public object Convert(object value, Type targetType, object parameter, string language)
        {
            int measurement = System.Convert.ToInt32(value);

            Range<int> range = this.GetValue(RangeProperty) as Range<int>;

            if (range == null)
            {
                return new SolidColorBrush(Colors.Gray);
            }

            if (measurement >= range.Min && measurement <= range.Max)
            {
                return new SolidColorBrush(Colors.LawnGreen);
            }

            return new SolidColorBrush(Colors.Red);
        }

        public object ConvertBack(object value, Type targetType, object parameter, string language)
        {
            // Just don't crash.
            return value;
        }
    }
}
